@@ -1,7 +1,7 @@
 package Finance::Currency::Convert::BI;
 
-our $DATE = '2016-02-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-07-29'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,6 @@ use warnings;
 use Log::Any::IfLOG '$log';
 
 use DateTime::Format::Indonesian;
-use LWP::Simple;
 use Parse::Number::ID qw(parse_number_id);
 
 use Exporter::Rinci qw(import);
@@ -29,11 +28,9 @@ _
     args => {
         from_date => {
             schema => 'date*',
-            'x.perl.coerce_to' => 'epoch',
         },
         to_date => {
             schema => 'date*',
-            'x.perl.coerce_to' => 'epoch',
         },
     },
 };
@@ -46,8 +43,17 @@ sub get_jisdor_rates {
     if ($args{_page_content}) {
         $page = $args{_page_content};
     } else {
-        $page = get "http://www.bi.go.id/id/moneter/informasi-kurs/referensi-jisdor/Default.aspx"
-            or return [500, "Can't retrieve BI page"];
+        require Mojo::UserAgent;
+        my $ua = Mojo::UserAgent->new;
+        my $tx = $ua->get("http://www.bi.go.id/id/moneter/informasi-kurs/referensi-jisdor/Default.aspx",
+                      {'User-Agent' => 'Mozilla/4.0'});
+        my $res = $tx->success;
+        if ($res) {
+            $page = $res->body;
+        } else {
+            my $err = $tx->error;
+            return [500, "Can't retrieve BI page: $err->{code} - $err->{message}"];
+        }
     }
 
     # XXX submit form if we want to set from_date & to_date
@@ -81,7 +87,7 @@ Finance::Currency::Convert::BI - Get/convert currencies from website of Indonesi
 
 =head1 VERSION
 
-This document describes version 0.02 of Finance::Currency::Convert::BI (from Perl distribution Finance-Currency-Convert-BI), released on 2016-02-05.
+This document describes version 0.03 of Finance::Currency::Convert::BI (from Perl distribution Finance-Currency-Convert-BI), released on 2016-07-29.
 
 =head1 SYNOPSIS
 
